@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2017 -- leonerd@leonerd.org.uk
 
 package Net::Async::WebSocket::Client;
 
@@ -17,12 +17,30 @@ use Scalar::Util qw( blessed );
 
 use URI;
 
-# In case URI doesn't know that ws:// and wss:// URIs use host/port
-require URI::_server;
-@URI::ws::ISA = ("URI::_server");
-@URI::wss::ISA = ("URI::_server");
+BEGIN {
+   eval {
+      require URI::wss;
+   } or do {
+      # In case URI doesn't know that ws:// and wss:// URIs use host/port
+      require URI::_server;
 
-our $VERSION = '0.10';
+      @URI::ws::ISA = qw( URI::_server );
+      *URI::ws::default_port = sub { 80 };
+
+      @URI::wss::ISA = qw( URI::_server );
+      *URI::wss::default_port = sub { 443 };
+      *URI::wss::secure = sub { 1 };
+   };
+
+   # We also need to support ->resource_name, which the CPAN module does not
+   # understand as of 2017-01-01
+   no warnings 'once';
+   *URI::wss::resource_name = sub {
+      shift->path_query
+   } unless URI::wss->can( "resource_name" );
+}
+
+our $VERSION = '0.11';
 
 use Protocol::WebSocket::Handshake::Client;
 
@@ -37,7 +55,7 @@ C<IO::Async>
  use Net::Async::WebSocket::Client;
 
  my $client = Net::Async::WebSocket::Client->new(
-    on_frame => sub {
+    on_text_frame => sub {
        my ( $self, $frame ) = @_;
        print $frame;
     },
@@ -49,7 +67,7 @@ C<IO::Async>
  $client->connect(
     url => "ws://$HOST:$PORT/",
  )->then( sub {
-    $client->send_frame( "Hello, world!\n" );
+    $client->send_text_frame( "Hello, world!\n" );
  })->get;
 
  $loop->run;
@@ -144,6 +162,11 @@ sub connect
 
       $params{host} //= $url->host;
       $params{service} //= $url->port;
+
+      if( $url->secure ) {
+         require IO::Async::SSL;
+         push @{ $params{extensions} }, qw( SSL );
+      }
    }
 
    my $on_connected = delete $params{on_connected};
